#
# spec file for package ghc-shelly
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name shelly
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.12.1
Release:        bp156.1.1
Summary:        Shell-like (systems) programming in Haskell
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-enclosed-exceptions-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-lifted-async-devel
BuildRequires:  ghc-lifted-base-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-hspec-contrib-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Shelly provides convenient systems programming in Haskell, similar in spirit to
POSIX shells. Shelly:

* is aimed at convenience and getting things done rather than being a
demonstration of elegance,

* has detailed and useful error messages,

* maintains its own environment, making it thread-safe.

Shelly is originally forked from the Shellish package.

See the shelly-extra package for additional functionality.

An overview is available in the README:
<https://github.com/gregwebs/Shelly.hs/blob/master/README.md>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Mon Apr  3 2023 Peter Simons <psimons@suse.com>
- Update shelly to version 1.12.1.
  [#] 1.12.1
  Andreas Abel, 2023-04-03
  * Add `print_commands_with` and `echoWith` which can be used to override
    the default printing functions (e.g. to add color).
    (Chris Wendt, PR [#228](https://github.com/gregwebs/Shelly.hs/pull/228).)
  * Tested with GHC 8.2 - 9.6 (cabal) and GHC 8.10 - 9.6 (stack).
  [#] 1.12.0.1
  Andreas Abel, 2023-04-02
  * Make `show_command` more robust to special characters
    and only quote when necessary.
    (Chris Wendt, PR [#229](https://github.com/gregwebs/Shelly.hs/pull/229).)
  * Tested with GHC 8.2 - 9.6 (cabal) and GHC 8.10 - 9.6 (stack).
  [#] 1.12.0
  Andreas Abel, 2023-02-27
  * Rework `ShellCmd` and `ShellCommand` instances to support `String` arguments:
    Issue [#143](https://github.com/gregwebs/Shelly.hs/issues/143)
    fixed by Cunning Defenstrator in
    PR [#221](https://github.com/gregwebs/Shelly.hs/pull/221).
    This involves a **breaking change** in classes `CmdArg` and `ShellArg`:
    Method `toTextArg` has been replaced by `toTextArgs`.
    Sample migration:
    ```haskell
    [#]if MIN_VERSION_shelly(1,12,0)
  - - new
    import Shelly (toTextArgs)
    snoc opts arg = opts ++ toTextArgs arg
    [#]else
  - - old
    import Shelly (toTextArg)
    snoc opts arg = opts ++ [ toTextArg arg ]
    [#]endif
    ```
  * Dropped GHC 8.0 to get rid of deprecated `LANGUAGE IncoherentInstances`.
  * Builds with GHC 8.2 - 9.6.
  [#] 1.11.0
  Andreas Abel, 2023-01-24
  * Restore running of local scripts, e.g. `cmd "./foo.sh"`:
    Issue [#107](https://github.com/gregwebs/Shelly.hs/issues/107)
    fixed by Alfredo di Napoli in PR
    [#216](https://github.com/gregwebs/Shelly.hs/pull/216).
  * Builds with GHC 8.0 - 9.4.
* Tue Jan 24 2023 Peter Simons <psimons@suse.com>
- Update shelly to version 1.10.0.1.
  [#] 1.10.0.1
  Andreas Abel, 2023-01-24
  * Allow `unix-compat-0.6`.
  * Builds `-Wall` warning-free with GHC 8.0 - 9.4.
* Mon Jan 31 2022 Peter Simons <psimons@suse.com>
- Update shelly to version 1.10.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/shelly-1.10.0/src/ChangeLog.md
* Sat Nov 20 2021 psimons@suse.com
- Update shelly to version 1.9.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update shelly to version 1.9.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add shelly at version 1.9.0.
